#!/bin/sh
# Licensed Materials - Property of IBM
# 5724-L68, 5724-L69.
# (C) Copyright IBM Corporation 2008. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

if test "a$1" = "a"
then
	echo "The script needs one of these parameters:"
	echo "CONFIG : To setup the UPDI if it is not setup"
	echo "DEPLOY : To deploy the WPG UPDI Console changes"
	echo "VERIFY : To update the response files and verify its properties"
	exit 0
else

	binDir=`dirname $0`

	if [ -f $binDir/bcgSetupCmdLine.sh ]
	then
		. $binDir/bcgSetupCmdLine.sh
	else
		echo "Please enter the absolute path to the Java installed location:"
		read path
		JAVA_HOME=$path
	fi

	if test "$JAVA_HOME" = ""
	then
		echo "Please enter the absolute path to the Java installed location:"
		read path
		JAVA_HOME=$path
	fi

	echo JAVA_HOME: $JAVA_HOME

	LOG4J_JARPATH="$binDir"/../updivalidation/log4j-1.2.13.jar
	UPDIUPDATE_JARPATH="$binDir"/../updivalidation/updivalidator.jar

	input=$1
	input=`echo $input | tr '[a-z]' '[A-Z]'`

	if test "$input" = "CONFIG"
	then
		echo "Please enter the path of the Common File System(CFS):"
		read CFSPath

		"$JAVA_HOME/bin/java" -classpath "$UPDIUPDATE_JARPATH:$LOG4J_JARPATH" com.ibm.bcg.updivalidation.UPDISetupScript $input $CFSPath
	elif test "$input" = "VERIFY"
	then
		echo "Please enter the path of the Common File System(CFS):"
		read CFSPath

		DIRECTORY="$binDir"/../properties/version/nif/update/config/install/lib

		if [ -d "$DIRECTORY" ]
		then
			for i in $DIRECTORY/*.*; do
			    PATH_TO_JARS=$PATH_TO_JARS:$i
			done

			"$JAVA_HOME/bin/java" -classpath "$PATH_TO_JARS:$UPDIUPDATE_JARPATH:$LOG4J_JARPATH" com.ibm.bcg.updivalidation.UPDIUpdateDBSysProps $CFSPath
			"$JAVA_HOME/bin/java" -classpath "$PATH_TO_JARS:$UPDIUPDATE_JARPATH:$LOG4J_JARPATH" com.ibm.bcg.updivalidation.UPDISetupScript $input $CFSPath
		else
			echo "$DIRECTORY location cannot be found. Please setup the UPDI first by running the script with CONFIG argument"
		fi
	elif test "$input" = "DEPLOY"
	then
		DIRECTORY="$binDir"/../properties/version/nif/update/config/install/lib

		if [ -d "$DIRECTORY" ]
		then
			for i in $DIRECTORY/*.*; do
			    PATH_TO_JARS=$PATH_TO_JARS:$i
			done

			"$JAVA_HOME/bin/java" -classpath "$PATH_TO_JARS:$UPDIUPDATE_JARPATH:$LOG4J_JARPATH" com.ibm.bcg.updivalidation.WPGEarUpdate
		else
			echo "$DIRECTORY location cannot be found. Please setup the UPDI first by running the script with CONFIG argument"
		fi
	else
		echo "The script needs either of these parameters:"
		echo "CONFIG : To setup the UPDI if it is not setup"
		echo "DEPLOY : To deploy the WPG UPDI Console changes"
		echo "VERIFY : To update the response files and verify its properties"
		exit 0
	fi
fi